# ansible-aap-api-client

| BRANCH  | STATUS                                                                                                                                                                                                                                                   |
|---------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| main    | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/ansible-aap-api-client/actions/workflows/test-coverage-lint.yml/badge.svg?branch=main)](https://github.com/btr1975/ansible-aap-api-client/actions/workflows/test-coverage-lint.yml)      |
| develop | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/ansible-aap-api-client/actions/workflows/test-coverage-lint.yml/badge.svg?branch=develop)](https://github.com/btr1975/ansible-aap-api-client/actions/workflows/test-coverage-lint.yml)    |

[![Supported Versions](https://img.shields.io/pypi/pyversions/ansible-aap-api-client.svg)](https://pypi.org/project/ansible-aap-api-client)

[![Downloads](https://pepy.tech/badge/ansible-aap-api-client)](https://pepy.tech/project/ansible-aap-api-client)

[![Docs](https://readthedocs.org/projects/ansible-aap-api-client/badge/?version=latest)](https://ansible-aap-api-client.readthedocs.io/en/latest/)

## Description
* A client to interact with Ansible AAP REST API

#### Generated by CookieCutter
* Repository: [GitHub](https://github.com/btr1975/cookiecutter-python-library)
* Version: 1.0.13
